@@ -70,6 +70,9 @@ class SharedBackendConf(SharedBackendConfUtils):
     def ldapLogin(self):
         return self._jconf.ldapLogin()
 
+    def proxyLoginOnly(self):
+        return self._jconf.proxyLoginOnly()
+
     def kerberosLogin(self):
         return self._jconf.kerberosLogin()
 
@@ -310,6 +313,14 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setLdapLoginDisabled()
         return self
 
+    def setProxyLoginOnlyEnabled(self):
+        self._jconf.setProxyLoginOnlyEnabled()
+        return self
+
+    def setProxyLoginOnlyDisabled(self):
+        self._jconf.setProxyLoginOnlyDisabled()
+        return self
+
     def setKerberosLoginEnabled(self):
         self._jconf.setKerberosLoginEnabled()
         return self
