@@ -17,7 +17,7 @@
 
 from warnings import warn
 from pyspark import keyword_only
-from ai.h2o.sparkling import Initializer
+from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
 from ai.h2o.sparkling.ml.algos.H2OSupervisedAlgorithm import H2OSupervisedAlgorithm
 from ai.h2o.sparkling.ml.params.H2OStackedEnsembleParams import H2OStackedEnsembleParams
@@ -35,7 +35,6 @@ class H2OStackedEnsemble(H2OStackedEnsembleParams, H2OSupervisedAlgorithm, H2OSt
                  withContributions=False,
                  dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
-                 namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
                  detailedPredictionCol="detailed_prediction",
                  validationDataFrame=None,
