@@ -36,7 +36,6 @@ class H2OGLMClassifier(H2OGLM):
                  withContributions=False,
                  dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
-                 namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
                  detailedPredictionCol="detailed_prediction",
                  validationDataFrame=None,
@@ -49,6 +48,7 @@ class H2OGLMClassifier(H2OGLM):
                  family="AUTO",
                  randomFamily=None,
                  tweedieVariancePower=0.0,
+                 dispersionLearningRate=0.5,
                  tweedieLinkPower=1.0,
                  theta=1.0E-10,
                  solver="AUTO",
@@ -61,6 +61,7 @@ class H2OGLMClassifier(H2OGLM):
                  standardize=True,
                  coldStart=False,
                  missingValuesHandling="MeanImputation",
+                 influence=None,
                  nonNegative=False,
                  maxIterations=-1,
                  betaEpsilon=1.0E-4,
@@ -68,10 +69,15 @@ class H2OGLMClassifier(H2OGLM):
                  gradientEpsilon=-1.0,
                  objReg=-1.0,
                  link="family_default",
+                 dispersionParameterMethod="pearson",
                  randomLink=None,
                  startval=None,
                  calcLike=False,
+                 generateVariableInflationFactors=False,
                  intercept=True,
+                 buildNullModel=False,
+                 fixDispersionParameter=False,
+                 initDispersionParameter=1.0,
                  HGLM=False,
                  prior=-1.0,
                  lambdaMinRatio=-1.0,
@@ -82,7 +88,11 @@ class H2OGLMClassifier(H2OGLM):
                  maxAfterBalanceSize=5.0,
                  maxConfusionMatrixSize=20,
                  computePValues=False,
+                 fixTweedieVariancePower=True,
                  removeCollinearCols=False,
+                 dispersionEpsilon=1.0E-4,
+                 tweedieEpsilon=8.0E-17,
+                 maxIterationsDispersion=3000,
                  generateScoringHistory=False,
                  modelId=None,
                  nfolds=0,
