@@ -21,6 +21,7 @@ from py4j.java_gateway import JavaObject
 from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.ml.models.H2OMOJOSettings import H2OMOJOSettings
 from ai.h2o.sparkling.ml.params.H2OTypeConverters import H2OTypeConverters
+from ai.h2o.sparkling.H2ODataFrameConverters import H2ODataFrameConverters
 from ai.h2o.sparkling.ml.params.HasIgnoredColsOnMOJO import HasIgnoredColsOnMOJO
 
 
@@ -137,9 +138,9 @@ class H2OKMeansMOJOModel(H2OUnsupervisedMOJOModelParams, HasIgnoredColsOnMOJO):
 
     def getCenters(self):
         value = self._java_obj.getCenters()
-        return H2OTypeConverters.scalaToPythonDataFrame(value)
+        return H2ODataFrameConverters.scalaToPythonDataFrame(value)
 
 
     def getCentersStd(self):
         value = self._java_obj.getCentersStd()
-        return H2OTypeConverters.scalaToPythonDataFrame(value)
+        return H2ODataFrameConverters.scalaToPythonDataFrame(value)
