@@ -131,6 +131,12 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
         """Handling of missing values. Either MeanImputation, Skip or PlugValues.""",
         H2OTypeConverters.toEnumString("hex.glm.GLMModel$GLMParameters$MissingValuesHandling"))
 
+    influence = Param(
+        Params._dummy(),
+        "influence",
+        """If set to dfbetas will calculate the difference in beta when a datarow is included and excluded in the dataset.""",
+        H2OTypeConverters.toNullableEnumString("hex.glm.GLMModel$GLMParameters$Influence"))
+
     nonNegative = Param(
         Params._dummy(),
         "nonNegative",
@@ -497,6 +503,9 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     def getMissingValuesHandling(self):
         return self.getOrDefault(self.missingValuesHandling)
 
+    def getInfluence(self):
+        return self.getOrDefault(self.influence)
+
     def getNonNegative(self):
         return self.getOrDefault(self.nonNegative)
 
@@ -707,6 +716,9 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     def setMissingValuesHandling(self, value):
         return self._set(missingValuesHandling=value)
 
+    def setInfluence(self, value):
+        return self._set(influence=value)
+
     def setNonNegative(self, value):
         return self._set(nonNegative=value)
 
