@@ -11,6 +11,7 @@ from h2o.utils.compatibility import *  # NOQA
 import warnings
 
 import h2o
+from h2o.display import format_user_tips, repr_def
 from h2o.expr import ExprNode
 from h2o.utils.typechecks import is_type
 
@@ -60,7 +61,6 @@ class GroupBy(object):
     Variance (var) and standard deviation (sd) are the sample (not population) statistics.
     """
 
-
     def __init__(self, fr, by):
         """
         Return a new ``GroupBy`` object using the H2OFrame specified in fr and the desired grouping columns
@@ -85,7 +85,6 @@ class GroupBy(object):
         else:
             self._by = [self._by]
 
-
     def min(self, col=None, na="all"):
         """
         Calculate the minimum of each column specified in col for each group of a GroupBy object.  If no col is
@@ -106,7 +105,6 @@ class GroupBy(object):
         """
         return self._add_agg("min", col, na)
 
-
     def max(self, col=None, na="all"):
         """
         Calculate the maximum of each column specified in col for each group of a GroupBy object.  If no col is
@@ -127,7 +125,6 @@ class GroupBy(object):
         """
         return self._add_agg("max", col, na)
 
-
     def mean(self, col=None, na="all"):
         """
         Calculate the mean of each column specified in col for each group of a GroupBy object.  If no col is
@@ -148,7 +145,6 @@ class GroupBy(object):
         """
         return self._add_agg("mean", col, na)
 
-
     def count(self, na="all"):
         """
         Count the number of rows in each group of a GroupBy object.
@@ -166,7 +162,6 @@ class GroupBy(object):
         """
         return self._add_agg("nrow", None, na)
 
-
     def sum(self, col=None, na="all"):
         """
         Calculate the sum of each column specified in col for each group of a GroupBy object.  If no col is given,
@@ -187,7 +182,6 @@ class GroupBy(object):
         """
         return self._add_agg("sum", col, na)
 
-
     def sd(self, col=None, na="all"):
         """
         Calculate the standard deviation of each column specified in col for each group of a GroupBy object. If no
@@ -208,7 +202,6 @@ class GroupBy(object):
         """
         return self._add_agg("sdev", col, na)
 
-
     def var(self, col=None, na="all"):
         """
         Calculate the variance of each column specified in col for each group of a GroupBy object.  If no col is
@@ -229,7 +222,6 @@ class GroupBy(object):
         """
         return self._add_agg("var", col, na)
 
-
     def ss(self, col=None, na="all"):
         """
         Calculate the sum of squares of each column specified in col for each group of a GroupBy object.  If no col
@@ -250,7 +242,6 @@ class GroupBy(object):
         """
         return self._add_agg("sumSquares", col, na)
 
-
     def mode(self, col=None, na="all"):
         """
         Calculate the mode of each column specified in col for each group of a GroupBy object.  If no col is given,
@@ -271,7 +262,6 @@ class GroupBy(object):
         """
         return self._add_agg("mode", col, na)
 
-
     def median(self, col=None, na="all"):
         """
         Calculate the median of each column specified in col for each group of a GroupBy object.  If no col is given,
@@ -292,7 +282,6 @@ class GroupBy(object):
         """
         return self._add_agg("median", col, na)
 
-
     @property
     def frame(self):
         """
@@ -306,7 +295,6 @@ class GroupBy(object):
         """
         return self.get_frame()
 
-
     def get_frame(self):
         """
         Return the resulting H2OFrame containing the result(s) of aggregation(s) of the group by.
@@ -347,7 +335,6 @@ class GroupBy(object):
 
         return self._res
 
-
     def _add_agg(self, op, col, na):
         if op == "nrow": col = 0
         if col is None:
@@ -373,8 +360,14 @@ class GroupBy(object):
             warnings.warn("Column {0} is a string column.  No groupby operation will be performed on it.".format(self._fr.names[colIndex]))
 
     def __repr__(self):
-        print("GroupBy: ")
-        print("  Frame: {}; by={}".format(self._fr.frame_id, str(self._by)))
-        print("  Aggregates: {}".format(str(self._aggs.keys())))
-        print("*** Use get_frame() to get groupby frame ***")
-        return ""
+        return repr_def(self, attributes=['_fr', '_by', '_aggs'])
+
+    def __str__(self):
+        return """GroupBy:
+          Frame: {frame}; by={by}
+          Aggregates: {aggr}
+        """.format(
+            frame=self._fr.frame_id,
+            by=self._by,
+            aggr=self._aggs.keys(),
+        )+format_user_tips("Use get_frame() to get groupby frame")
